macro_rules! export {
() => { ... };
($path:expr $(,)?) => { ... };
}Expand description
Export TypeScript API definitions for all collected endpoints to a file
macro_rules! export {
() => { ... };
($path:expr $(,)?) => { ... };
}Export TypeScript API definitions for all collected endpoints to a file